Crate webtrans_trait

Crate webtrans_trait 

Traits

Error
Error trait for WebTransport operations.
MaybeSend
A trait that is Send on native targets and a no-op on WASM.
MaybeSync
A trait that is Sync on native targets and a no-op on WASM.
RecvStream
An incoming stream of bytes from the peer.
SendStream
An outgoing stream of bytes to the peer.
Session
A WebTransport session that can accept/create streams and send/receive datagrams.