Traits
- Error
- Error trait for WebTransport operations.
- Maybe
Send - A trait that is Send on native targets and a no-op on WASM.
- Maybe
Sync - A trait that is Sync on native targets and a no-op on WASM.
- Recv
Stream - An incoming stream of bytes from the peer.
- Send
Stream - An outgoing stream of bytes to the peer.
- Session
- A WebTransport session that can accept/create streams and send/receive datagrams.